import { Client } from 'pg';
import type { AdapterBoundPool, AdapterPrimalPool, AdapterConfig, AdapterTableNames, AdapterTableNamesProps } from '@resolve-js/eventstore-base';
declare type EscapeFunction = (source: string) => string;
declare type FullJitter = (retries: number) => number;
declare type ConnectionOptions = {
    user: string;
    database: string;
    port: number;
    host: string;
    password: string;
};
export declare type ConfiguredProps = AdapterTableNamesProps & {
    Postgres: typeof Client;
    connectionOptions: ConnectionOptions;
    databaseName: string;
    fullJitter: FullJitter;
    executeStatement: (sql: string, useDistinctConnection?: boolean) => Promise<any[]>;
    escapeId: EscapeFunction;
    escape: EscapeFunction;
    getVacantTimeInMillis?: () => number;
    createGetConnectPromise: () => () => Promise<void>;
    getConnectPromise: () => Promise<void>;
    connection?: Client;
};
export declare type PostgresqlAdapterConfig = AdapterConfig & AdapterTableNames & ConnectionOptions & {
    databaseName: string;
};
export declare type AdapterPool = AdapterBoundPool<ConfiguredProps>;
export declare type AdapterPoolPrimal = AdapterPrimalPool<ConfiguredProps>;
export declare type PostgresResourceConfig = {
    user: PostgresqlAdapterConfig['user'];
    database: PostgresqlAdapterConfig['database'];
    databaseName: PostgresqlAdapterConfig['databaseName'];
    host: PostgresqlAdapterConfig['host'];
    port: PostgresqlAdapterConfig['port'];
    password: PostgresqlAdapterConfig['password'];
    userLogin: string;
};
export { Client as PostgresConnection };
